# $BEGIN_AUDIOMATH_LICENSE$
# 
# This file is part of the audiomath project, a Python package for
# recording, manipulating and playing sound files.
# 
# Copyright (c) 2017-2019 Jeremy Hill
# 
# audiomath is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program. If not, see http://www.gnu.org/licenses/ .
# 
# $END_AUDIOMATH_LICENSE$

__all__ = [
	
]

from . import Dependencies;         from .Dependencies import numpy
from . import DependencyManagement; from .DependencyManagement import LoadPyplot
from . import Base;                 from .Base import Sound

def Plot( self, hold=False, zeroBased=False, maxDuration=60 ):
	y = self.y
	if maxDuration is not None and maxDuration < self.duration:
		durationStr = 'infinite duration' if numpy.isinf( self.nSamples ) else 'nominal duration %g sec' % self.duration
		#typeStr = 'an array' if isinstance( y, numpy.ndarray ) else 'a ' + y.__class__.__name__
		typeStr = 'a %s' % self.__class__.__name__
		print( 'Plotting only the first %g seconds of %s of %s' % ( maxDuration, typeStr, durationStr ) )
		y = self[ :maxDuration ].y
	y = numpy.asarray( y ) / -2.0
	y = numpy.clip( y, -0.5, 0.5 )
	offset = numpy.arange( Base.NumberOfChannels( y ) )
	if not zeroBased: offset += 1
	y += offset
	t = numpy.arange( 0, Base.NumberOfSamples( y ) ) / float( self.fs )

	plt = LoadPyplot()
	if not hold: plt.cla()
	h = plt.plot( t, y )
	ax = plt.gca()
	ax.set_yticks( offset )
	ax.set_ylim( offset.max() + 1, offset.min() - 1 )
	ax.set_xlim( t[ 0 ], t[ -1 ] )
	ax.xaxis.grid( True )
	ax.yaxis.grid( True )
	plt.draw()
Sound.Plot = Plot
